summaryrefslogtreecommitdiffstats
path: root/cc/thread_proxy.cc
diff options
context:
space:
mode:
Diffstat (limited to 'cc/thread_proxy.cc')
-rw-r--r--cc/thread_proxy.cc7
1 files changed, 4 insertions, 3 deletions
diff --git a/cc/thread_proxy.cc b/cc/thread_proxy.cc
index 9e7773c..ddc61c0 100644
--- a/cc/thread_proxy.cc
+++ b/cc/thread_proxy.cc
@@ -1176,9 +1176,10 @@ void ThreadProxy::renewTreePriority()
if (m_smoothnessTakesPriorityExpirationTime > base::TimeTicks::Now())
priority = SMOOTHNESS_TAKES_PRIORITY;
- // New content always takes priority when we have an active tree with
- // evicted resources.
- if (m_layerTreeHostImpl->activeTree()->ContentsTexturesPurged())
+ // New content always takes priority when the active tree has
+ // evicted resources or there is an invalid viewport size.
+ if (m_layerTreeHostImpl->activeTree()->ContentsTexturesPurged() ||
+ m_layerTreeHostImpl->activeTree()->ViewportSizeInvalid())
priority = NEW_CONTENT_TAKES_PRIORITY;
m_layerTreeHostImpl->setTreePriority(priority);